aboutsummaryrefslogtreecommitdiffstats
path: root/eth/protocol.go
diff options
context:
space:
mode:
authorPéter Szilágyi <peterke@gmail.com>2018-05-20 00:39:28 +0800
committerGitHub <noreply@github.com>2018-05-20 00:39:28 +0800
commit953b5ac015da7fdef39c6864bb0cb490ffaa7959 (patch)
tree0a1b93effde4276c64a1c62ff97f25a5cd2deb7f /eth/protocol.go
parentf9c456e02d6b8320389a7ea95c0eef3e10a87e2e (diff)
parent49719e21bcd740c5890334f8c0ec8ac3777fb4c6 (diff)
downloaddexon-953b5ac015da7fdef39c6864bb0cb490ffaa7959.tar
dexon-953b5ac015da7fdef39c6864bb0cb490ffaa7959.tar.gz
dexon-953b5ac015da7fdef39c6864bb0cb490ffaa7959.tar.bz2
dexon-953b5ac015da7fdef39c6864bb0cb490ffaa7959.tar.lz
dexon-953b5ac015da7fdef39c6864bb0cb490ffaa7959.tar.xz
dexon-953b5ac015da7fdef39c6864bb0cb490ffaa7959.tar.zst
dexon-953b5ac015da7fdef39c6864bb0cb490ffaa7959.zip
Merge pull request #16720 from rjl493456442/PreTxsEvent
all: collate new transaction events together
Diffstat (limited to 'eth/protocol.go')
-rw-r--r--eth/protocol.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/eth/protocol.go b/eth/protocol.go
index 328d5b993..0e90e6a2e 100644
--- a/eth/protocol.go
+++ b/eth/protocol.go
@@ -103,9 +103,9 @@ type txPool interface {
// The slice should be modifiable by the caller.
Pending() (map[common.Address]types.Transactions, error)
- // SubscribeTxPreEvent should return an event subscription of
- // TxPreEvent and send events to the given channel.
- SubscribeTxPreEvent(chan<- core.TxPreEvent) event.Subscription
+ // SubscribeNewTxsEvent should return an event subscription of
+ // NewTxsEvent and send events to the given channel.
+ SubscribeNewTxsEvent(chan<- core.NewTxsEvent) event.Subscription
}
// statusData is the network packet for the status message.